=========
Changelog
=========

All notable changes to this project will be documented in this file.


[0.1.7] - 11 November 2025

Added
-----

* New ``hide_think_mode_button`` field for hiding the think mode button.
* New ``hide_tooltips`` field for hiding the tooltips.
* New ``think_mode_enabled`` field for enabling the think mode.
* New ``think_mode_button_text`` field for configuring the think mode button text.

[0.1.7] - 15 September 2025
===========================

Added
-----

* New ``hide_sources`` field for hiding sources.


[0.1.6] - 29 August 2025
========================

Added
-----

* New ``ai_icon`` field for configuring the AI icon type.
* New ``hide_avatars`` field for hiding avatar display.

[1.0.5] - 22 June 2025
=======================

Added
-----

* New ``api_key`` field for configuration.

[1.0.4] - 24 May 2025
======================

Changed
-------

* Enhanced BielExtension with additional configuration options: ``disable_input``, ``email``, ``expand_modal``, ``hide_close_button``, ``hide_expand_button``, ``hide_refresh_button``, ``hide_feedback``, ``modal_position``, ``show_terms_modal``, ``error_message_4_0_3``, ``error_message_4_0_4``, ``error_message_default``, ``footer_text``, ``header_title``, ``input_placeholder_text``, ``send_button_text``, ``sources_text``, ``suggested_questions``, ``suggested_questions_title``, ``terms_checkbox_text``, ``terms_description``, ``terms_title``, ``welcome_message``.

[1.3.3] - 16 April 2025
========================

Added
-----

* Latest configuration options including ``custom_font``, ``email``, ``hide_icon``, ``input_placeholder_text``, ``send_button_text``, ``suggested_questions_title``, ``show_terms_modal``, ``terms_title``, ``terms_description``, and ``terms_checkbox_text``.

[0.1.2] - 24 February 2025
===========================

Changed
-------

* Open source code release.

[0.1.0] - 03 August 2023
========================

Added
-----

* Initial code release.
